@@ -1,6 +1,6 @@
 package Dancer2::Core::Role::SessionFactory::File;
 # ABSTRACT: Role for file-based session factories
-$Dancer2::Core::Role::SessionFactory::File::VERSION = '0.166001';
+$Dancer2::Core::Role::SessionFactory::File::VERSION = '1.1.0';
 use Moo::Role;
 with 'Dancer2::Core::Role::SessionFactory';
 
@@ -8,6 +8,7 @@ use Carp 'croak';
 use Dancer2::Core::Types;
 use Dancer2::FileUtils qw(path set_file_mode escape_filename);
 use Fcntl ':flock';
+use File::Copy ();
 
 #--------------------------------------------------------------------------#
 # Required by classes consuming this role
@@ -63,7 +64,7 @@ sub _retrieve {
     my ( $self, $id ) = @_;
     my $session_file = path( $self->session_dir, escape_filename($id) . $self->_suffix );
 
-    return unless -f $session_file;
+    croak "Invalid session ID: $id" unless -f $session_file;
 
     open my $fh, '+<', $session_file or die "Can't open '$session_file': $!\n";
     flock $fh, LOCK_SH or die "Can't lock file '$session_file': $!\n";
@@ -73,6 +74,20 @@ sub _retrieve {
     return $data;
 }
 
+sub _change_id {
+    my ($self, $old_id, $new_id) = @_;
+
+    my $old_path =
+      path($self->session_dir, escape_filename($old_id) . $self->_suffix);
+
+    return if !-f $old_path;
+
+    my $new_path =
+      path($self->session_dir, escape_filename($new_id) . $self->_suffix);
+
+    File::Copy::move($old_path, $new_path);
+}
+
 sub _destroy {
     my ( $self, $id ) = @_;
     my $session_file = path( $self->session_dir, escape_filename($id) . $self->_suffix );
@@ -110,7 +125,7 @@ Dancer2::Core::Role::SessionFactory::File - Role for file-based session factorie
 
 =head1 VERSION
 
-version 0.166001
+version 1.1.0
 
 =head1 DESCRIPTION
 
@@ -123,13 +138,14 @@ serialization and deserialization.
 Classes consuming this must satisfy three requirements: C<_suffix>,
 C<_freeze_to_handle> and C<_thaw_from_handle>.
 
-    package Dancer2::SessionFactory::XYX
+    package Dancer2::Session::XYX;
 
+    use Dancer2::Core::Types;
     use Moo;
 
     has _suffix => (
         is      => 'ro',
-        isa     => 'Str',
+        isa     => Str,
         default => sub { '.xyz' },
     );
 
@@ -166,7 +182,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Alexis Sukrieh.
+This software is copyright (c) 2023 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
